'use strict';

var index = require('./index-DX7gStMP.js');

const Alien = props => {
    const hex = props.hex || 'currentColor';
    const klass = props.class;
    const label = props.label || 'alien';
    const size = props.size || 24;
    return (index.h("svg", { class: klass, width: size, height: size, viewBox: "0 0 24 24", role: "img", "aria-label": "title" },
        index.h("title", null, label),
        index.h("g", { fill: hex },
            index.h("path", { d: "M10.31 10.93C11.33 12.57 11.18 14.5 9.96 15.28C8.74 16.04 6.92 15.33\n      5.89 13.69C4.87 12.05 5.03 10.1 6.25 9.34C7.47 8.58 9.29 9.29 10.31\n      10.93M12 17.75C14 17.75 14.5 17 14.5 17C14.5 17 14 19 12 19C10 19 9.5\n      17.03 9.5 17C9.5 17 10 17.75 12 17.75M17.75 9.34C18.97 10.1 19.13 12.05\n      18.11 13.69C17.08 15.33 15.26 16.04 14.04 15.28C12.82 14.5 12.67 12.57\n      13.69 10.93C14.71 9.29 16.53 8.58 17.75 9.34M12 20C14.5 20 20 14.86 20\n      11C20 7.14 16.41 4 12 4C7.59 4 4 7.14 4 11C4 14.86 9.5 20 12 20M12 2C17.5\n      2 22 6.04 22 11C22 15.08 16.32 22 12 22C7.68 22 2 15.08 2 11C2 6.04 6.5 2\n      12 2Z" })),
        index.h("path", { d: "M0 0h24v24H0z", fill: "none" })));
};

const KEY = 'proto-sudoku';
const DATA = `${KEY}::data`;
const INPUTS = `${KEY}::inputs`;
const PICK = `${KEY}::pick`;
const getForKey = (key) => {
    const json = localStorage.getItem(key);
    return json ? JSON.parse(json) : undefined;
};
const storeForKey = (key, value) => {
    const json = JSON.stringify(value);
    localStorage.setItem(key, json);
};
const bag = {
    get: () => {
        return getForKey(DATA);
    },
    store: value => {
        storeForKey(DATA, value);
    },
    inputs: {
        get: () => {
            const line = getForKey(INPUTS);
            return [...line];
        },
        store: (value) => {
            storeForKey(INPUTS, value.join(''));
        },
    },
    pick: {
        get: () => {
            const pick = getForKey(PICK);
            return pick !== null ? pick : undefined;
        },
        store: (value) => {
            storeForKey(PICK, value >= 0 && value < 81 ? value : null);
        },
    },
};

const CHECK = 'Check ?';
const DELETE = 'x';
const NEW_PUZZLE = 'New Puzzle';

const appendToMap = (map, propName, value) => {
    const items = map.get(propName);
    if (!items) {
        map.set(propName, [value]);
    }
    else if (!items.includes(value)) {
        items.push(value);
    }
};
const debounce = (fn, ms) => {
    let timeoutId;
    return (...args) => {
        if (timeoutId) {
            clearTimeout(timeoutId);
        }
        timeoutId = setTimeout(() => {
            timeoutId = 0;
            fn(...args);
        }, ms);
    };
};

/**
 * Check if a possible element isConnected.
 * The property might not be there, so we check for it.
 *
 * We want it to return true if isConnected is not a property,
 * otherwise we would remove these elements and would not update.
 *
 * Better leak in Edge than to be useless.
 */
const isConnected = (maybeElement) => !('isConnected' in maybeElement) || maybeElement.isConnected;
const cleanupElements = debounce((map) => {
    for (let key of map.keys()) {
        map.set(key, map.get(key).filter(isConnected));
    }
}, 2_000);
const stencilSubscription = () => {
    if (typeof index.getRenderingRef !== 'function') {
        // If we are not in a stencil project, we do nothing.
        // This function is not really exported by @stencil/core.
        return {};
    }
    const elmsToUpdate = new Map();
    return {
        dispose: () => elmsToUpdate.clear(),
        get: (propName) => {
            const elm = index.getRenderingRef();
            if (elm) {
                appendToMap(elmsToUpdate, propName, elm);
            }
        },
        set: (propName) => {
            const elements = elmsToUpdate.get(propName);
            if (elements) {
                elmsToUpdate.set(propName, elements.filter(index.forceUpdate));
            }
            cleanupElements(elmsToUpdate);
        },
        reset: () => {
            elmsToUpdate.forEach((elms) => elms.forEach(index.forceUpdate));
            cleanupElements(elmsToUpdate);
        },
    };
};

const unwrap = (val) => (typeof val === 'function' ? val() : val);
const createObservableMap = (defaultState, shouldUpdate = (a, b) => a !== b) => {
    const unwrappedState = unwrap(defaultState);
    let states = new Map(Object.entries(unwrappedState ?? {}));
    const handlers = {
        dispose: [],
        get: [],
        set: [],
        reset: [],
    };
    const reset = () => {
        // When resetting the state, the default state may be a function - unwrap it to invoke it.
        // otherwise, the state won't be properly reset
        states = new Map(Object.entries(unwrap(defaultState) ?? {}));
        handlers.reset.forEach((cb) => cb());
    };
    const dispose = () => {
        // Call first dispose as resetting the state would
        // cause less updates ;)
        handlers.dispose.forEach((cb) => cb());
        reset();
    };
    const get = (propName) => {
        handlers.get.forEach((cb) => cb(propName));
        return states.get(propName);
    };
    const set = (propName, value) => {
        const oldValue = states.get(propName);
        if (shouldUpdate(value, oldValue, propName)) {
            states.set(propName, value);
            handlers.set.forEach((cb) => cb(propName, value, oldValue));
        }
    };
    const state = (typeof Proxy === 'undefined'
        ? {}
        : new Proxy(unwrappedState, {
            get(_, propName) {
                return get(propName);
            },
            ownKeys(_) {
                return Array.from(states.keys());
            },
            getOwnPropertyDescriptor() {
                return {
                    enumerable: true,
                    configurable: true,
                };
            },
            has(_, propName) {
                return states.has(propName);
            },
            set(_, propName, value) {
                set(propName, value);
                return true;
            },
        }));
    const on = (eventName, callback) => {
        handlers[eventName].push(callback);
        return () => {
            removeFromArray(handlers[eventName], callback);
        };
    };
    const onChange = (propName, cb) => {
        const unSet = on('set', (key, newValue) => {
            if (key === propName) {
                cb(newValue);
            }
        });
        // We need to unwrap the defaultState because it might be a function.
        // Otherwise we might not be sending the right reset value.
        const unReset = on('reset', () => cb(unwrap(defaultState)[propName]));
        return () => {
            unSet();
            unReset();
        };
    };
    const use = (...subscriptions) => {
        const unsubs = subscriptions.reduce((unsubs, subscription) => {
            if (subscription.set) {
                unsubs.push(on('set', subscription.set));
            }
            if (subscription.get) {
                unsubs.push(on('get', subscription.get));
            }
            if (subscription.reset) {
                unsubs.push(on('reset', subscription.reset));
            }
            if (subscription.dispose) {
                unsubs.push(on('dispose', subscription.dispose));
            }
            return unsubs;
        }, []);
        return () => unsubs.forEach((unsub) => unsub());
    };
    const forceUpdate = (key) => {
        const oldValue = states.get(key);
        handlers.set.forEach((cb) => cb(key, oldValue, oldValue));
    };
    return {
        state,
        get,
        set,
        on,
        onChange,
        use,
        dispose,
        reset,
        forceUpdate,
    };
};
const removeFromArray = (array, item) => {
    const index = array.indexOf(item);
    if (index >= 0) {
        array[index] = array[array.length - 1];
        array.length--;
    }
};

const createStore = (defaultState, shouldUpdate) => {
    const map = createObservableMap(defaultState, shouldUpdate);
    map.use(stencilSubscription());
    return map;
};

class HTTPError extends Error {
    response;
    request;
    options;
    constructor(response, request, options) {
        const code = (response.status || response.status === 0) ? response.status : '';
        const title = response.statusText || '';
        const status = `${code} ${title}`.trim();
        const reason = status ? `status code ${status}` : 'an unknown error';
        super(`Request failed with ${reason}: ${request.method} ${request.url}`);
        this.name = 'HTTPError';
        this.response = response;
        this.request = request;
        this.options = options;
    }
}

class TimeoutError extends Error {
    request;
    constructor(request) {
        super(`Request timed out: ${request.method} ${request.url}`);
        this.name = 'TimeoutError';
        this.request = request;
    }
}

const supportsRequestStreams = (() => {
    let duplexAccessed = false;
    let hasContentType = false;
    const supportsReadableStream = typeof globalThis.ReadableStream === 'function';
    const supportsRequest = typeof globalThis.Request === 'function';
    if (supportsReadableStream && supportsRequest) {
        try {
            hasContentType = new globalThis.Request('https://empty.invalid', {
                body: new globalThis.ReadableStream(),
                method: 'POST',
                // @ts-expect-error - Types are outdated.
                get duplex() {
                    duplexAccessed = true;
                    return 'half';
                },
            }).headers.has('Content-Type');
        }
        catch (error) {
            // QQBrowser on iOS throws "unsupported BodyInit type" error (see issue #581)
            if (error instanceof Error && error.message === 'unsupported BodyInit type') {
                return false;
            }
            throw error;
        }
    }
    return duplexAccessed && !hasContentType;
})();
const supportsAbortController = typeof globalThis.AbortController === 'function';
const supportsResponseStreams = typeof globalThis.ReadableStream === 'function';
const supportsFormData = typeof globalThis.FormData === 'function';
const requestMethods = ['get', 'post', 'put', 'patch', 'head', 'delete'];
const responseTypes = {
    json: 'application/json',
    text: 'text/*',
    formData: 'multipart/form-data',
    arrayBuffer: '*/*',
    blob: '*/*',
};
// The maximum value of a 32bit int (see issue #117)
const maxSafeTimeout = 2_147_483_647;
// Size in bytes of a typical form boundary, used to help estimate upload size
const usualFormBoundarySize = new TextEncoder().encode('------WebKitFormBoundaryaxpyiPgbbPti10Rw').length;
const stop = Symbol('stop');
const kyOptionKeys = {
    json: true,
    parseJson: true,
    stringifyJson: true,
    searchParams: true,
    prefixUrl: true,
    retry: true,
    timeout: true,
    hooks: true,
    throwHttpErrors: true,
    onDownloadProgress: true,
    onUploadProgress: true,
    fetch: true,
};
const requestOptionsRegistry = {
    method: true,
    headers: true,
    body: true,
    mode: true,
    credentials: true,
    cache: true,
    redirect: true,
    referrer: true,
    referrerPolicy: true,
    integrity: true,
    keepalive: true,
    signal: true,
    window: true,
    dispatcher: true,
    duplex: true,
    priority: true,
};

// eslint-disable-next-line @typescript-eslint/ban-types
const getBodySize = (body) => {
    if (!body) {
        return 0;
    }
    if (body instanceof FormData) {
        // This is an approximation, as FormData size calculation is not straightforward
        let size = 0;
        for (const [key, value] of body) {
            size += usualFormBoundarySize;
            size += new TextEncoder().encode(`Content-Disposition: form-data; name="${key}"`).length;
            size += typeof value === 'string'
                ? new TextEncoder().encode(value).length
                : value.size;
        }
        return size;
    }
    if (body instanceof Blob) {
        return body.size;
    }
    if (body instanceof ArrayBuffer) {
        return body.byteLength;
    }
    if (typeof body === 'string') {
        return new TextEncoder().encode(body).length;
    }
    if (body instanceof URLSearchParams) {
        return new TextEncoder().encode(body.toString()).length;
    }
    if ('byteLength' in body) {
        return (body).byteLength;
    }
    if (typeof body === 'object' && body !== null) {
        try {
            const jsonString = JSON.stringify(body);
            return new TextEncoder().encode(jsonString).length;
        }
        catch {
            return 0;
        }
    }
    return 0; // Default case, unable to determine size
};
const streamResponse = (response, onDownloadProgress) => {
    const totalBytes = Number(response.headers.get('content-length')) || 0;
    let transferredBytes = 0;
    if (response.status === 204) {
        if (onDownloadProgress) {
            onDownloadProgress({ percent: 1, totalBytes, transferredBytes }, new Uint8Array());
        }
        return new Response(null, {
            status: response.status,
            statusText: response.statusText,
            headers: response.headers,
        });
    }
    return new Response(new ReadableStream({
        async start(controller) {
            const reader = response.body.getReader();
            if (onDownloadProgress) {
                onDownloadProgress({ percent: 0, transferredBytes: 0, totalBytes }, new Uint8Array());
            }
            async function read() {
                const { done, value } = await reader.read();
                if (done) {
                    controller.close();
                    return;
                }
                if (onDownloadProgress) {
                    transferredBytes += value.byteLength;
                    const percent = totalBytes === 0 ? 0 : transferredBytes / totalBytes;
                    onDownloadProgress({ percent, transferredBytes, totalBytes }, value);
                }
                controller.enqueue(value);
                await read();
            }
            await read();
        },
    }), {
        status: response.status,
        statusText: response.statusText,
        headers: response.headers,
    });
};
const streamRequest = (request, onUploadProgress) => {
    const totalBytes = getBodySize(request.body);
    let transferredBytes = 0;
    return new Request(request, {
        // @ts-expect-error - Types are outdated.
        duplex: 'half',
        body: new ReadableStream({
            async start(controller) {
                const reader = request.body instanceof ReadableStream ? request.body.getReader() : new Response('').body.getReader();
                async function read() {
                    const { done, value } = await reader.read();
                    if (done) {
                        // Ensure 100% progress is reported when the upload is complete
                        if (onUploadProgress) {
                            onUploadProgress({ percent: 1, transferredBytes, totalBytes: Math.max(totalBytes, transferredBytes) }, new Uint8Array());
                        }
                        controller.close();
                        return;
                    }
                    transferredBytes += value.byteLength;
                    let percent = totalBytes === 0 ? 0 : transferredBytes / totalBytes;
                    if (totalBytes < transferredBytes || percent === 1) {
                        percent = 0.99;
                    }
                    if (onUploadProgress) {
                        onUploadProgress({ percent: Number(percent.toFixed(2)), transferredBytes, totalBytes }, value);
                    }
                    controller.enqueue(value);
                    await read();
                }
                await read();
            },
        }),
    });
};

// eslint-disable-next-line @typescript-eslint/ban-types
const isObject = (value) => value !== null && typeof value === 'object';

const validateAndMerge = (...sources) => {
    for (const source of sources) {
        if ((!isObject(source) || Array.isArray(source)) && source !== undefined) {
            throw new TypeError('The `options` argument must be an object');
        }
    }
    return deepMerge({}, ...sources);
};
const mergeHeaders = (source1 = {}, source2 = {}) => {
    const result = new globalThis.Headers(source1);
    const isHeadersInstance = source2 instanceof globalThis.Headers;
    const source = new globalThis.Headers(source2);
    for (const [key, value] of source.entries()) {
        if ((isHeadersInstance && value === 'undefined') || value === undefined) {
            result.delete(key);
        }
        else {
            result.set(key, value);
        }
    }
    return result;
};
function newHookValue(original, incoming, property) {
    return (Object.hasOwn(incoming, property) && incoming[property] === undefined)
        ? []
        : deepMerge(original[property] ?? [], incoming[property] ?? []);
}
const mergeHooks = (original = {}, incoming = {}) => ({
    beforeRequest: newHookValue(original, incoming, 'beforeRequest'),
    beforeRetry: newHookValue(original, incoming, 'beforeRetry'),
    afterResponse: newHookValue(original, incoming, 'afterResponse'),
    beforeError: newHookValue(original, incoming, 'beforeError'),
});
// TODO: Make this strongly-typed (no `any`).
const deepMerge = (...sources) => {
    let returnValue = {};
    let headers = {};
    let hooks = {};
    for (const source of sources) {
        if (Array.isArray(source)) {
            if (!Array.isArray(returnValue)) {
                returnValue = [];
            }
            returnValue = [...returnValue, ...source];
        }
        else if (isObject(source)) {
            for (let [key, value] of Object.entries(source)) {
                if (isObject(value) && key in returnValue) {
                    value = deepMerge(returnValue[key], value);
                }
                returnValue = { ...returnValue, [key]: value };
            }
            if (isObject(source.hooks)) {
                hooks = mergeHooks(hooks, source.hooks);
                returnValue.hooks = hooks;
            }
            if (isObject(source.headers)) {
                headers = mergeHeaders(headers, source.headers);
                returnValue.headers = headers;
            }
        }
    }
    return returnValue;
};

const normalizeRequestMethod = (input) => requestMethods.includes(input) ? input.toUpperCase() : input;
const retryMethods = ['get', 'put', 'head', 'delete', 'options', 'trace'];
const retryStatusCodes = [408, 413, 429, 500, 502, 503, 504];
const retryAfterStatusCodes = [413, 429, 503];
const defaultRetryOptions = {
    limit: 2,
    methods: retryMethods,
    statusCodes: retryStatusCodes,
    afterStatusCodes: retryAfterStatusCodes,
    maxRetryAfter: Number.POSITIVE_INFINITY,
    backoffLimit: Number.POSITIVE_INFINITY,
    delay: attemptCount => 0.3 * (2 ** (attemptCount - 1)) * 1000,
};
const normalizeRetryOptions = (retry = {}) => {
    if (typeof retry === 'number') {
        return {
            ...defaultRetryOptions,
            limit: retry,
        };
    }
    if (retry.methods && !Array.isArray(retry.methods)) {
        throw new Error('retry.methods must be an array');
    }
    if (retry.statusCodes && !Array.isArray(retry.statusCodes)) {
        throw new Error('retry.statusCodes must be an array');
    }
    return {
        ...defaultRetryOptions,
        ...retry,
    };
};

// `Promise.race()` workaround (#91)
async function timeout(request, init, abortController, options) {
    return new Promise((resolve, reject) => {
        const timeoutId = setTimeout(() => {
            if (abortController) {
                abortController.abort();
            }
            reject(new TimeoutError(request));
        }, options.timeout);
        void options
            .fetch(request, init)
            .then(resolve)
            .catch(reject)
            .then(() => {
            clearTimeout(timeoutId);
        });
    });
}

// https://github.com/sindresorhus/delay/tree/ab98ae8dfcb38e1593286c94d934e70d14a4e111
async function delay(ms, { signal }) {
    return new Promise((resolve, reject) => {
        if (signal) {
            signal.throwIfAborted();
            signal.addEventListener('abort', abortHandler, { once: true });
        }
        function abortHandler() {
            clearTimeout(timeoutId);
            reject(signal.reason);
        }
        const timeoutId = setTimeout(() => {
            signal?.removeEventListener('abort', abortHandler);
            resolve();
        }, ms);
    });
}

const findUnknownOptions = (request, options) => {
    const unknownOptions = {};
    for (const key in options) {
        if (!(key in requestOptionsRegistry) && !(key in kyOptionKeys) && !(key in request)) {
            unknownOptions[key] = options[key];
        }
    }
    return unknownOptions;
};

class Ky {
    static create(input, options) {
        const ky = new Ky(input, options);
        const function_ = async () => {
            if (typeof ky._options.timeout === 'number' && ky._options.timeout > maxSafeTimeout) {
                throw new RangeError(`The \`timeout\` option cannot be greater than ${maxSafeTimeout}`);
            }
            // Delay the fetch so that body method shortcuts can set the Accept header
            await Promise.resolve();
            // Before using ky.request, _fetch clones it and saves the clone for future retries to use.
            // If retry is not needed, close the cloned request's ReadableStream for memory safety.
            let response = await ky._fetch();
            for (const hook of ky._options.hooks.afterResponse) {
                // eslint-disable-next-line no-await-in-loop
                const modifiedResponse = await hook(ky.request, ky._options, ky._decorateResponse(response.clone()));
                if (modifiedResponse instanceof globalThis.Response) {
                    response = modifiedResponse;
                }
            }
            ky._decorateResponse(response);
            if (!response.ok && ky._options.throwHttpErrors) {
                let error = new HTTPError(response, ky.request, ky._options);
                for (const hook of ky._options.hooks.beforeError) {
                    // eslint-disable-next-line no-await-in-loop
                    error = await hook(error);
                }
                throw error;
            }
            // If `onDownloadProgress` is passed, it uses the stream API internally
            if (ky._options.onDownloadProgress) {
                if (typeof ky._options.onDownloadProgress !== 'function') {
                    throw new TypeError('The `onDownloadProgress` option must be a function');
                }
                if (!supportsResponseStreams) {
                    throw new Error('Streams are not supported in your environment. `ReadableStream` is missing.');
                }
                return streamResponse(response.clone(), ky._options.onDownloadProgress);
            }
            return response;
        };
        const isRetriableMethod = ky._options.retry.methods.includes(ky.request.method.toLowerCase());
        const result = (isRetriableMethod ? ky._retry(function_) : function_())
            .finally(async () => {
            // Now that we know a retry is not needed, close the ReadableStream of the cloned request.
            if (!ky.request.bodyUsed) {
                await ky.request.body?.cancel();
            }
        });
        for (const [type, mimeType] of Object.entries(responseTypes)) {
            result[type] = async () => {
                // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
                ky.request.headers.set('accept', ky.request.headers.get('accept') || mimeType);
                const response = await result;
                if (type === 'json') {
                    if (response.status === 204) {
                        return '';
                    }
                    const arrayBuffer = await response.clone().arrayBuffer();
                    const responseSize = arrayBuffer.byteLength;
                    if (responseSize === 0) {
                        return '';
                    }
                    if (options.parseJson) {
                        return options.parseJson(await response.text());
                    }
                }
                return response[type]();
            };
        }
        return result;
    }
    request;
    abortController;
    _retryCount = 0;
    _input;
    _options;
    // eslint-disable-next-line complexity
    constructor(input, options = {}) {
        this._input = input;
        this._options = {
            ...options,
            headers: mergeHeaders(this._input.headers, options.headers),
            hooks: mergeHooks({
                beforeRequest: [],
                beforeRetry: [],
                beforeError: [],
                afterResponse: [],
            }, options.hooks),
            method: normalizeRequestMethod(options.method ?? this._input.method ?? 'GET'),
            // eslint-disable-next-line @typescript-eslint/prefer-nullish-coalescing
            prefixUrl: String(options.prefixUrl || ''),
            retry: normalizeRetryOptions(options.retry),
            throwHttpErrors: options.throwHttpErrors !== false,
            timeout: options.timeout ?? 10_000,
            fetch: options.fetch ?? globalThis.fetch.bind(globalThis),
        };
        if (typeof this._input !== 'string' && !(this._input instanceof URL || this._input instanceof globalThis.Request)) {
            throw new TypeError('`input` must be a string, URL, or Request');
        }
        if (this._options.prefixUrl && typeof this._input === 'string') {
            if (this._input.startsWith('/')) {
                throw new Error('`input` must not begin with a slash when using `prefixUrl`');
            }
            if (!this._options.prefixUrl.endsWith('/')) {
                this._options.prefixUrl += '/';
            }
            this._input = this._options.prefixUrl + this._input;
        }
        if (supportsAbortController) {
            const originalSignal = this._options.signal ?? this._input.signal;
            this.abortController = new globalThis.AbortController();
            this._options.signal = originalSignal ? AbortSignal.any([originalSignal, this.abortController.signal]) : this.abortController.signal;
        }
        if (supportsRequestStreams) {
            // @ts-expect-error - Types are outdated.
            this._options.duplex = 'half';
        }
        if (this._options.json !== undefined) {
            this._options.body = this._options.stringifyJson?.(this._options.json) ?? JSON.stringify(this._options.json);
            this._options.headers.set('content-type', this._options.headers.get('content-type') ?? 'application/json');
        }
        this.request = new globalThis.Request(this._input, this._options);
        if (this._options.searchParams) {
            // eslint-disable-next-line unicorn/prevent-abbreviations
            const textSearchParams = typeof this._options.searchParams === 'string'
                ? this._options.searchParams.replace(/^\?/, '')
                : new URLSearchParams(this._options.searchParams).toString();
            // eslint-disable-next-line unicorn/prevent-abbreviations
            const searchParams = '?' + textSearchParams;
            const url = this.request.url.replace(/(?:\?.*?)?(?=#|$)/, searchParams);
            // To provide correct form boundary, Content-Type header should be deleted each time when new Request instantiated from another one
            if (((supportsFormData && this._options.body instanceof globalThis.FormData)
                || this._options.body instanceof URLSearchParams) && !(this._options.headers && this._options.headers['content-type'])) {
                this.request.headers.delete('content-type');
            }
            // The spread of `this.request` is required as otherwise it misses the `duplex` option for some reason and throws.
            this.request = new globalThis.Request(new globalThis.Request(url, { ...this.request }), this._options);
        }
        // If `onUploadProgress` is passed, it uses the stream API internally
        if (this._options.onUploadProgress) {
            if (typeof this._options.onUploadProgress !== 'function') {
                throw new TypeError('The `onUploadProgress` option must be a function');
            }
            if (!supportsRequestStreams) {
                throw new Error('Request streams are not supported in your environment. The `duplex` option for `Request` is not available.');
            }
            const originalBody = this.request.body;
            if (originalBody) {
                this.request = streamRequest(this.request, this._options.onUploadProgress);
            }
        }
    }
    _calculateRetryDelay(error) {
        this._retryCount++;
        if (this._retryCount > this._options.retry.limit || error instanceof TimeoutError) {
            throw error;
        }
        if (error instanceof HTTPError) {
            if (!this._options.retry.statusCodes.includes(error.response.status)) {
                throw error;
            }
            const retryAfter = error.response.headers.get('Retry-After')
                ?? error.response.headers.get('RateLimit-Reset')
                ?? error.response.headers.get('X-RateLimit-Reset') // GitHub
                ?? error.response.headers.get('X-Rate-Limit-Reset'); // Twitter
            if (retryAfter && this._options.retry.afterStatusCodes.includes(error.response.status)) {
                let after = Number(retryAfter) * 1000;
                if (Number.isNaN(after)) {
                    after = Date.parse(retryAfter) - Date.now();
                }
                else if (after >= Date.parse('2024-01-01')) {
                    // A large number is treated as a timestamp (fixed threshold protects against clock skew)
                    after -= Date.now();
                }
                const max = this._options.retry.maxRetryAfter ?? after;
                return after < max ? after : max;
            }
            if (error.response.status === 413) {
                throw error;
            }
        }
        const retryDelay = this._options.retry.delay(this._retryCount);
        return Math.min(this._options.retry.backoffLimit, retryDelay);
    }
    _decorateResponse(response) {
        if (this._options.parseJson) {
            response.json = async () => this._options.parseJson(await response.text());
        }
        return response;
    }
    async _retry(function_) {
        try {
            return await function_();
        }
        catch (error) {
            const ms = Math.min(this._calculateRetryDelay(error), maxSafeTimeout);
            if (this._retryCount < 1) {
                throw error;
            }
            await delay(ms, { signal: this._options.signal });
            for (const hook of this._options.hooks.beforeRetry) {
                // eslint-disable-next-line no-await-in-loop
                const hookResult = await hook({
                    request: this.request,
                    options: this._options,
                    error: error,
                    retryCount: this._retryCount,
                });
                // If `stop` is returned from the hook, the retry process is stopped
                if (hookResult === stop) {
                    return;
                }
            }
            return this._retry(function_);
        }
    }
    async _fetch() {
        for (const hook of this._options.hooks.beforeRequest) {
            // eslint-disable-next-line no-await-in-loop
            const result = await hook(this.request, this._options);
            if (result instanceof Request) {
                this.request = result;
                break;
            }
            if (result instanceof Response) {
                return result;
            }
        }
        const nonRequestOptions = findUnknownOptions(this.request, this._options);
        // Cloning is done here to prepare in advance for retries
        const mainRequest = this.request;
        this.request = mainRequest.clone();
        if (this._options.timeout === false) {
            return this._options.fetch(mainRequest, nonRequestOptions);
        }
        return timeout(mainRequest, nonRequestOptions, this.abortController, this._options);
    }
}

/*! MIT License © Sindre Sorhus */
const createInstance = (defaults) => {
    // eslint-disable-next-line @typescript-eslint/promise-function-async
    const ky = (input, options) => Ky.create(input, validateAndMerge(defaults, options));
    for (const method of requestMethods) {
        // eslint-disable-next-line @typescript-eslint/promise-function-async
        ky[method] = (input, options) => Ky.create(input, validateAndMerge(defaults, options, { method }));
    }
    ky.create = (newDefaults) => createInstance(validateAndMerge(newDefaults));
    ky.extend = (newDefaults) => {
        if (typeof newDefaults === 'function') {
            newDefaults = newDefaults(defaults ?? {});
        }
        return createInstance(validateAndMerge(defaults, newDefaults));
    };
    ky.stop = stop;
    return ky;
};
const ky = createInstance();

// --------------------------------------------------------[ mutable store ]
const storeDef = {
    list: [],
    keys: [],
    locs: [],
    loading: false,
    solved: false,
    error: undefined,
    pick: undefined,
    data: undefined,
};
const { state } = createStore(storeDef);
// --------------------------------------------------------[ geometry ]
// NOTE:  by using Sets here, we don't have to worry about clearing geometry...
const geometry = new Map([
    ['row', new Map()],
    ['column', new Map()],
    ['box', new Map()],
]);
const keyValues = ['1', '2', '3', '4', '5', '6', '7', '8', '9'];
const computeBox = (row, column) => {
    if (column < 3) {
        return row < 3 ? 0 : row < 6 ? 3 : 6;
    }
    else {
        if (column < 6) {
            return row < 3 ? 1 : row < 6 ? 4 : 7;
        }
        else {
            return row < 3 ? 2 : row < 6 ? 5 : 8;
        }
    }
};
const computeLocs = (index, row, column, box) => {
    const data = new Map([
        ['row', row],
        ['column', column],
        ['box', box],
    ]);
    const locs = new Set();
    data.forEach((value, key) => {
        geometry
            .get(key)
            .get(value)
            .forEach(indx => {
            indx !== index && locs.add(indx);
        });
    });
    return Array.from(locs);
};
const computeKeys = locs => {
    const { list } = state;
    const found = new Set();
    locs.map(indx => {
        const { key } = list[indx];
        if (key != '.') {
            found.add(key);
        }
    });
    const keys = keyValues.filter(key => !found.has(key));
    return keys;
};
const updateGeometry = (index, row, column, box) => {
    const data = new Map([
        ['row', row],
        ['column', column],
        ['box', box],
    ]);
    data.forEach((value, key) => {
        const map = geometry.get(key);
        if (map.has(value)) {
            // looking at the set specification, it should be sufficient to just call add
            // https://tc39.es/ecma262/#sec-set.prototype.add
            map.get(value).add(index);
        }
        else {
            map.set(value, new Set([index]));
        }
    });
};
const updateFromInputs = list => {
    const inputs = bag.inputs.get();
    inputs.forEach((key, indx) => {
        const cell = list[indx];
        const { isClue } = cell;
        if (!isClue) {
            cell.key = key;
        }
    });
};
// --------------------------------------------------------[ process ]
const processData = (next) => {
    if (next) {
        const { puzzle, ref } = next;
        const cells = puzzle ? [...puzzle] : [];
        const line = ref ? atob(ref) : undefined; // decrypt the solution... [ base64 ]
        const solution = line ? [...line] : [];
        const list = cells.map((key, indx) => {
            const value = solution[indx];
            const isClue = key === value;
            const row = Math.floor(indx / 9);
            const column = indx % 9;
            const box = computeBox(row, column);
            updateGeometry(indx, row, column, box);
            return { key, isClue, value, indx, row, column, box };
        });
        // NOTE:  this only happens once on data change...
        updateFromInputs(list);
        state.data = next;
        state.list = list;
    }
    else {
        state.data = undefined;
        state.list = [];
    }
};
const processPick = (next) => {
    if (next !== undefined && next.indx != state.pick) {
        const { isClue, indx, row, column, box } = next;
        const locs = computeLocs(indx, row, column, box);
        const keys = isClue ? [] : computeKeys(locs);
        state.pick = indx;
        state.keys = keys;
        state.locs = locs;
        // NOTE:  we could auto-pick if there's only one key...
        // (keys.length === 1) && next.key = keys[0];
    }
    else {
        state.pick = undefined;
        state.keys = [];
        state.locs = [];
    }
    savePick(state.pick);
};
// --------------------------------------------------------[ utils ]
let api = undefined;
const platformPrefix = {
    local: 'http://localhost:8080/api',
    netlify: '/.netlify/functions',
    vercel: 'https://sudoku-rust-api.vercel.app/api',
};
const getPrefixFor = (platform) => {
    const keys = Object.keys(platformPrefix);
    const target = keys.includes(platform) ? platform : 'vercel';
    return platformPrefix[target];
};
const initApi = (platform) => {
    const prefix = getPrefixFor(platform);
    api = ky.extend({
        hooks: {
            beforeRequest: [
                request => {
                    request.headers.set('X-Requested-With', 'ky');
                    request.headers.set('X-Custom-Header', 'foobar');
                },
            ],
        },
        prefixUrl: prefix,
        timeout: 10000,
    });
};
const saveInputs = (inputs) => {
    bag.inputs.store(inputs);
};
const savePick = (pick) => {
    bag.pick.store(pick);
};
const clearStore = (loading = false) => {
    state.list = [];
    state.keys = [];
    state.locs = [];
    state.loading = loading;
    state.solved = false;
    state.error = undefined;
    state.pick = undefined;
    state.data = undefined;
};
const updateStore = (data, save = true) => {
    const { puzzle, ref } = data;
    if (save) {
        bag.inputs.store([]);
        bag.store(data);
    }
    processData({ puzzle, ref });
};
// --------------------------------------------------------[ actions ]
const initApp = (platform) => {
    initApi(platform);
    clearStore();
    // this retrieves the last data we stored in the bag...
    const data = bag.get();
    const pick = bag.pick.get();
    if (data) {
        updateStore(data, false);
        if (pick >= 0) {
            const { list } = state;
            const cell = list[pick];
            processPick(cell);
        }
    }
};
const refresh = async () => {
    clearStore(true);
    saveInputs([]);
    savePick(state.pick);
    try {
        // fetch a new puzzle from the api...
        const data = await api.get('puzzle').json();
        updateStore(data);
    }
    catch (err) {
        // handle error...
        const { message } = err;
        console.log('-- ', message);
        console.log(err);
        state.error = message;
    }
    finally {
        // always executed
        state.loading = false;
    }
};
const select = (cell) => {
    processPick(cell);
};
const redraw = (list) => {
    state.list = [...list];
    list.length = 0;
};
const check = () => {
    const { list } = state;
    const inputs = [];
    let errors = 0;
    let found = 0;
    let clues = 0;
    list.forEach(cell => {
        const { key, value, isClue } = cell;
        if (!isClue) {
            if (key !== '.') {
                if (key !== value) {
                    errors = errors + 1;
                    cell.key = '.';
                }
                else {
                    found = found + 1;
                }
            }
        }
        else {
            clues = clues + 1;
        }
        inputs.push(cell.key);
    });
    const total = clues + found;
    found ? saveInputs(inputs) : saveInputs([]);
    if (errors > 0) {
        redraw(list);
    }
    else {
        if (total === 81) {
            state.solved = true;
        }
    }
};
const input = (key) => {
    const { pick, list } = state;
    const cell = list[pick];
    cell.key = key;
    redraw(list);
};
const actions = {
    initApp,
    refresh,
    select,
    check,
    input,
};

// WARNING:  generated file...
const TW_VERSION = '4.1.10';

const tw = (...classes) => {
    return classes.filter(Boolean).join(' ');
};

const Spinner = props => {
    const hex = props.hex || 'currentColor';
    const klass = props.class || '';
    const label = props.label || 'loading...';
    const size = props.size || 24;
    return (index.h("svg", { class: tw(klass, 'animate-spin'), width: size, height: size, fill: "none", viewBox: "0 0 24 24", role: "img", "aria-label": "title" },
        index.h("title", null, label),
        index.h("g", null,
            index.h("circle", { class: "opacity-25", cx: "12", cy: "12", r: "10", stroke: hex, "stroke-width": "4" }),
            index.h("path", { class: "opacity-75", fill: hex, d: "M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z" })),
        index.h("path", { d: "M0 0h24v24H0z", fill: "none" })));
};

const Alert = props => {
    const { message, salute, spinner = false } = props;
    return (index.h("div", { class: "mt-5 flex h-24px flex-row items-center" },
        spinner ? index.h(Spinner, { class: "mr-2" }) : index.h(Alien, { class: "mr-2" }),
        salute ? index.h("label", { class: "mr-1 font-bold" },
            salute,
            ":") : '',
        index.h("label", { class: "italic" }, message)));
};

const Alerts = _props => {
    const { solved, loading, error } = state;
    const play = !loading && !error && !solved;
    return (index.h("div", { class: "flex flex-col" },
        play ? index.h(Alert, { message: "Welcome, are you ready to play?..." }) : '',
        loading ? index.h(Alert, { message: "Loading...", spinner: true }) : '',
        error ? index.h(Alert, { message: error, salute: "ERROR" }) : '',
        solved ? index.h(Alert, { message: "You solved the puzzle!!" }) : ''));
};

const Fingerprint = props => {
    const hex = props.hex || 'currentColor';
    const klass = props.class;
    const label = props.label || 'fingerprint';
    const size = props.size || 24;
    return (index.h("svg", { class: klass, width: size, height: size, viewBox: "0 0 24 24", role: "img", "aria-label": "title" },
        index.h("title", null, label),
        index.h("g", { fill: hex },
            index.h("path", { d: "M17.81,4.47C17.73,4.47 17.65,4.45 17.58,4.41C15.66,3.42 14,3\n      12,3C10.03,3 8.15,3.47 6.44,4.41C6.2,4.54 5.9,4.45 5.76,4.21C5.63,3.97\n      5.72,3.66 5.96,3.53C7.82,2.5 9.86,2 12,2C14.14,2 16,2.47\n      18.04,3.5C18.29,3.65 18.38,3.95 18.25,4.19C18.16,4.37 18,4.47\n      17.81,4.47M3.5,9.72C3.4,9.72 3.3,9.69 3.21,9.63C3,9.47 2.93,9.16\n      3.09,8.93C4.08,7.53 5.34,6.43 6.84,5.66C10,4.04 14,4.03\n      17.15,5.65C18.65,6.42 19.91,7.5 20.9,8.9C21.06,9.12 21,9.44\n      20.78,9.6C20.55,9.76 20.24,9.71 20.08,9.5C19.18,8.22 18.04,7.23\n      16.69,6.54C13.82,5.07 10.15,5.07 7.29,6.55C5.93,7.25 4.79,8.25\n      3.89,9.5C3.81,9.65 3.66,9.72 3.5,9.72M9.75,21.79C9.62,21.79 9.5,21.74\n      9.4,21.64C8.53,20.77 8.06,20.21 7.39,19C6.7,17.77 6.34,16.27\n      6.34,14.66C6.34,11.69 8.88,9.27 12,9.27C15.12,9.27 17.66,11.69\n      17.66,14.66A0.5,0.5 0 0,1 17.16,15.16A0.5,0.5 0 0,1\n      16.66,14.66C16.66,12.24 14.57,10.27 12,10.27C9.43,10.27 7.34,12.24\n      7.34,14.66C7.34,16.1 7.66,17.43 8.27,18.5C8.91,19.66 9.35,20.15\n      10.12,20.93C10.31,21.13 10.31,21.44 10.12,21.64C10,21.74 9.88,21.79\n      9.75,21.79M16.92,19.94C15.73,19.94 14.68,19.64 13.82,19.05C12.33,18.04\n      11.44,16.4 11.44,14.66A0.5,0.5 0 0,1 11.94,14.16A0.5,0.5 0 0,1\n      12.44,14.66C12.44,16.07 13.16,17.4 14.38,18.22C15.09,18.7 15.92,18.93\n      16.92,18.93C17.16,18.93 17.56,18.9 17.96,18.83C18.23,18.78 18.5,18.96\n      18.54,19.24C18.59,19.5 18.41,19.77 18.13,19.82C17.56,19.93 17.06,19.94\n      16.92,19.94M14.91,22C14.87,22 14.82,22 14.78,22C13.19,21.54 12.15,20.95\n      11.06,19.88C9.66,18.5 8.89,16.64 8.89,14.66C8.89,13.04 10.27,11.72\n      11.97,11.72C13.67,11.72 15.05,13.04 15.05,14.66C15.05,15.73 16,16.6\n      17.13,16.6C18.28,16.6 19.21,15.73 19.21,14.66C19.21,10.89 15.96,7.83\n      11.96,7.83C9.12,7.83 6.5,9.41 5.35,11.86C4.96,12.67 4.76,13.62\n      4.76,14.66C4.76,15.44 4.83,16.67 5.43,18.27C5.53,18.53 5.4,18.82\n      5.14,18.91C4.88,19 4.59,18.87 4.5,18.62C4,17.31 3.77,16\n      3.77,14.66C3.77,13.46 4,12.37 4.45,11.42C5.78,8.63 8.73,6.82\n      11.96,6.82C16.5,6.82 20.21,10.33 20.21,14.65C20.21,16.27 18.83,17.59\n      17.13,17.59C15.43,17.59 14.05,16.27 14.05,14.65C14.05,13.58 13.12,12.71\n      11.97,12.71C10.82,12.71 9.89,13.58 9.89,14.65C9.89,16.36 10.55,17.96\n      11.76,19.16C12.71,20.1 13.62,20.62 15.03,21C15.3,21.08 15.45,21.36\n      15.38,21.62C15.33,21.85 15.12,22 14.91,22Z" })),
        index.h("path", { d: "M0 0h24v24H0z", fill: "none" })));
};

const url = 'https://eswat2.dev';
const who = 'eswat2';
const Eswat2Io = _props => {
    return (index.h("a", { class: "absolute right-0 top-0 text-clrs-gray hover:text-clrs-navy", href: url, "aria-label": who, target: "blank", title: who },
        index.h(Fingerprint, { label: who })));
};

const Header = (_props, children) => {
    return (index.h("h1", { class: tw('text-center uppercase text-clrs-red', 'mb-11 ml-0 mr-0 mt-11', 'text-6xl font-thin') }, children));
};

const Button = props => {
    const { label, callback, matched = false } = props;
    return (index.h("button", { class: tw('rounded-md border border-solid border-clrs-slate4 font-bold', label === CHECK
            ? 'mr-2 bg-clrs-yellow px-3 py-2 text-clrs-navy'
            : label === NEW_PUZZLE
                ? 'mr-2 bg-clrs-navy px-3 py-2 text-white'
                : label === DELETE
                    ? 'mr-1 bg-clrs-red px-2 py-1 text-white'
                    : matched
                        ? 'mr-1 bg-clrs-slate4 px-2 py-1 text-white'
                        : 'mr-1 bg-gray-50 px-2 py-1 text-clrs-navy'), onClick: callback }, label));
};

const Keys = _props => {
    const { keys, list, pick, solved } = state;
    const genHandler = (key) => {
        return () => {
            actions.input(key);
        };
    };
    const values = solved ? [] : keys;
    const cell = pick != undefined ? list[pick] : undefined;
    return (index.h("div", { class: "mt-2 flex flex-row justify-end" },
        !solved && cell && !cell.isClue && cell.key != '.' ? (index.h(Button, { label: DELETE, callback: genHandler('.') })) : (''),
        values.map((key) => {
            return (index.h(Button, { label: key, callback: genHandler(key), matched: cell.key === key }));
        })));
};

// NOTE: building indx mapping for the border highlighting...
const borderRight = [
    2, 5, 11, 14, 20, 23, 29, 32, 38, 41, 47, 50, 56, 59, 65, 68, 74, 77,
];
const borderLeft = borderRight.map(key => key + 1);
const borderBottom = [
    18, 19, 20, 21, 22, 23, 24, 25, 26, 45, 46, 47, 48, 49, 50, 51, 52, 53,
];
const borderTop = borderBottom.map(key => key + 9);
// Functional components return JSX...
const Cell = props => {
    const { cell, focus, selected, solved } = props;
    const { key, isClue, indx } = cell;
    const clue = key != '.' ? key : '';
    const genHandler = (cell, solved) => {
        return () => {
            if (!solved) {
                actions.select(cell);
            }
        };
    };
    return (index.h("label", { class: tw(`cell-${indx}`, borderRight.includes(indx) ? 'border-xbr-clrs-navy' : '', borderLeft.includes(indx) ? 'border-xbl-clrs-navy' : '', borderBottom.includes(indx) ? 'border-xbb-clrs-navy' : '', borderTop.includes(indx) ? 'border-xbt-clrs-navy' : '', 'h-8 w-8 border border-solid text-center leading-8', selected
            ? 'border-clrs-red bg-clrs-red-a50 text-clrs-red'
            : focus
                ? 'border-clrs-gray bg-clrs-green-a50 font-bold'
                : isClue
                    ? 'border-clrs-gray bg-clrs-silver'
                    : clue !== ''
                        ? 'border-clrs-gray text-clrs-red'
                        : 'border-clrs-gray'), onClick: genHandler(cell, solved) }, clue));
};

const SudokuBoard = _props => {
    const { list, pick, locs, solved } = state;
    return (index.h("div", { class: tw('flex flex-row flex-wrap', 'border border-solid border-clrs-navy', 'h-76p5 w-76p5 text-lg') }, list.map((cell, index$1) => {
        const selected = solved ? false : index$1 === pick;
        const focus = solved ? false : locs.includes(index$1);
        return (index.h(Cell, { cell: cell, focus: focus, selected: selected, solved: solved }));
    })));
};

const TwLabel = _props => {
    return (index.h("label", { class: "ml-auto align-top text-xs italic text-clrs-slate4" },
        "Tailwind ",
        TW_VERSION));
};

const handleRefresh = (actions) => {
    return () => {
        actions.refresh();
    };
};
const handleCheck = (actions) => {
    return () => {
        actions.check();
    };
};
const ToolBar = _props => {
    const { list, solved } = state;
    return (index.h("div", { class: "flex flex-row" },
        index.h(Button, { label: NEW_PUZZLE, callback: handleRefresh(actions) }),
        list.length === 81 && !solved ? (index.h(Button, { label: CHECK, callback: handleCheck(actions) })) : (''),
        index.h(TwLabel, null)));
};

const shadowCss = "/*! tailwindcss v4.1.10 | MIT License | https://tailwindcss.com */\n@layer properties;\n@layer theme, base, components, utilities;\n@layer theme {\n  :root,\n  :host {\n    --font-sans:\n      ui-sans-serif, system-ui, sans-serif, 'Apple Color Emoji',\n      'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji';\n    --color-gray-50: oklch(98.5% 0.002 247.839);\n    --color-white: #fff;\n    --spacing: 0.25rem;\n    --text-xs: 0.75rem;\n    --text-xs--line-height: calc(1 / 0.75);\n    --text-lg: 1.125rem;\n    --text-lg--line-height: calc(1.75 / 1.125);\n    --text-6xl: 3.75rem;\n    --text-6xl--line-height: 1;\n    --font-weight-thin: 100;\n    --font-weight-bold: 700;\n    --radius-md: 0.375rem;\n    --animate-spin: spin 1s linear infinite;\n  }\n}\n@layer utilities {\n  .absolute {\n    position: absolute;\n  }\n  .relative {\n    position: relative;\n  }\n  .top-0 {\n    top: calc(var(--spacing) * 0);\n  }\n  .right-0 {\n    right: calc(var(--spacing) * 0);\n  }\n  .m-6 {\n    margin: calc(var(--spacing) * 6);\n  }\n  .mt-2 {\n    margin-top: calc(var(--spacing) * 2);\n  }\n  .mt-5 {\n    margin-top: calc(var(--spacing) * 5);\n  }\n  .mt-11 {\n    margin-top: calc(var(--spacing) * 11);\n  }\n  .mr-0 {\n    margin-right: calc(var(--spacing) * 0);\n  }\n  .mr-1 {\n    margin-right: calc(var(--spacing) * 1);\n  }\n  .mr-2 {\n    margin-right: calc(var(--spacing) * 2);\n  }\n  .mb-11 {\n    margin-bottom: calc(var(--spacing) * 11);\n  }\n  .ml-0 {\n    margin-left: calc(var(--spacing) * 0);\n  }\n  .ml-auto {\n    margin-left: auto;\n  }\n  .flex {\n    display: flex;\n  }\n  .h-8 {\n    height: calc(var(--spacing) * 8);\n  }\n  .h-24px {\n    height: 24px;\n  }\n  .h-76p5 {\n    height: 19.125rem;\n  }\n  .w-8 {\n    width: calc(var(--spacing) * 8);\n  }\n  .w-76p5 {\n    width: 19.125rem;\n  }\n  .max-w-min {\n    max-width: min-content;\n  }\n  .animate-spin {\n    animation: var(--animate-spin);\n  }\n  .flex-col {\n    flex-direction: column;\n  }\n  .flex-row {\n    flex-direction: row;\n  }\n  .flex-wrap {\n    flex-wrap: wrap;\n  }\n  .items-center {\n    align-items: center;\n  }\n  .justify-end {\n    justify-content: flex-end;\n  }\n  .rounded-md {\n    border-radius: var(--radius-md);\n  }\n  .border {\n    border-style: var(--tw-border-style);\n    border-width: 1px;\n  }\n  .border-solid {\n    --tw-border-style: solid;\n    border-style: solid;\n  }\n  .border-clrs-gray {\n    border-color: var(--clrs-gray, #aaaaaa);\n  }\n  .border-clrs-navy {\n    border-color: var(--clrs-navy, #001f3f);\n  }\n  .border-clrs-red {\n    border-color: var(--clrs-red, #ff4136);\n  }\n  .border-clrs-slate4 {\n    border-color: var(--clrs-slate4, #4e5964);\n  }\n  .bg-clrs-green-a50 {\n    background-color: var(--clrs-green-a50, #2ecc4050);\n  }\n  .bg-clrs-navy {\n    background-color: var(--clrs-navy, #001f3f);\n  }\n  .bg-clrs-red {\n    background-color: var(--clrs-red, #ff4136);\n  }\n  .bg-clrs-red-a50 {\n    background-color: var(--clrs-red-a50, #ff413650);\n  }\n  .bg-clrs-silver {\n    background-color: var(--clrs-silver, #dddddd);\n  }\n  .bg-clrs-slate4 {\n    background-color: var(--clrs-slate4, #4e5964);\n  }\n  .bg-clrs-yellow {\n    background-color: var(--clrs-yellow, #ffdc00);\n  }\n  .bg-gray-50 {\n    background-color: var(--color-gray-50);\n  }\n  .p-0\\.5 {\n    padding: calc(var(--spacing) * 0.5);\n  }\n  .px-2 {\n    padding-inline: calc(var(--spacing) * 2);\n  }\n  .px-3 {\n    padding-inline: calc(var(--spacing) * 3);\n  }\n  .py-1 {\n    padding-block: calc(var(--spacing) * 1);\n  }\n  .py-2 {\n    padding-block: calc(var(--spacing) * 2);\n  }\n  .text-center {\n    text-align: center;\n  }\n  .align-top {\n    vertical-align: top;\n  }\n  .font-sans {\n    font-family: var(--font-sans);\n  }\n  .text-6xl {\n    font-size: var(--text-6xl);\n    line-height: var(--tw-leading, var(--text-6xl--line-height));\n  }\n  .text-lg {\n    font-size: var(--text-lg);\n    line-height: var(--tw-leading, var(--text-lg--line-height));\n  }\n  .text-xs {\n    font-size: var(--text-xs);\n    line-height: var(--tw-leading, var(--text-xs--line-height));\n  }\n  .leading-8 {\n    --tw-leading: calc(var(--spacing) * 8);\n    line-height: calc(var(--spacing) * 8);\n  }\n  .font-bold {\n    --tw-font-weight: var(--font-weight-bold);\n    font-weight: var(--font-weight-bold);\n  }\n  .font-thin {\n    --tw-font-weight: var(--font-weight-thin);\n    font-weight: var(--font-weight-thin);\n  }\n  .text-clrs-gray {\n    color: var(--clrs-gray, #aaaaaa);\n  }\n  .text-clrs-navy {\n    color: var(--clrs-navy, #001f3f);\n  }\n  .text-clrs-red {\n    color: var(--clrs-red, #ff4136);\n  }\n  .text-clrs-slate4 {\n    color: var(--clrs-slate4, #4e5964);\n  }\n  .text-white {\n    color: var(--color-white);\n  }\n  .uppercase {\n    text-transform: uppercase;\n  }\n  .italic {\n    font-style: italic;\n  }\n  .opacity-25 {\n    opacity: 25%;\n  }\n  .opacity-75 {\n    opacity: 75%;\n  }\n  .shadow {\n    --tw-shadow:\n      0 1px 3px 0 var(--tw-shadow-color, rgb(0 0 0 / 0.1)),\n      0 1px 2px -1px var(--tw-shadow-color, rgb(0 0 0 / 0.1));\n    box-shadow:\n      var(--tw-inset-shadow), var(--tw-inset-ring-shadow),\n      var(--tw-ring-offset-shadow), var(--tw-ring-shadow), var(--tw-shadow);\n  }\n  .border-xbb-clrs-navy {\n    border-bottom: 1px solid var(--clrs-navy, #001f3f) !important;\n  }\n  .border-xbl-clrs-navy {\n    border-left: 1px solid var(--clrs-navy, #001f3f) !important;\n  }\n  .border-xbr-clrs-navy {\n    border-right: 1px solid var(--clrs-navy, #001f3f) !important;\n  }\n  .border-xbt-clrs-navy {\n    border-top: 1px solid var(--clrs-navy, #001f3f) !important;\n  }\n  .hover\\:text-clrs-navy {\n    &:hover {\n      @media (hover: hover) {\n        color: var(--clrs-navy, #001f3f);\n      }\n    }\n  }\n}\n@layer components {\n  .ds1-main {\n    margin: calc(var(--spacing) * 6);\n    display: flex;\n    flex-direction: column;\n    font-family: var(--font-sans);\n    color: var(--clrs-navy, #001f3f);\n    -webkit-font-smoothing: antialiased;\n    -moz-osx-font-smoothing: grayscale;\n  }\n}\n@keyframes spin {\n  to {\n    transform: rotate(360deg);\n  }\n}\n@layer properties {\n  @supports ((-webkit-hyphens: none) and (not (margin-trim: inline))) or\n    ((-moz-orient: inline) and (not (color: rgb(from red r g b)))) {\n    *,\n    ::before,\n    ::after,\n    ::backdrop {\n      --tw-border-style: solid;\n      --tw-leading: initial;\n      --tw-font-weight: initial;\n      --tw-shadow: 0 0 #0000;\n      --tw-shadow-color: initial;\n      --tw-shadow-alpha: 100%;\n      --tw-inset-shadow: 0 0 #0000;\n      --tw-inset-shadow-color: initial;\n      --tw-inset-shadow-alpha: 100%;\n      --tw-ring-color: initial;\n      --tw-ring-shadow: 0 0 #0000;\n      --tw-inset-ring-color: initial;\n      --tw-inset-ring-shadow: 0 0 #0000;\n      --tw-ring-inset: initial;\n      --tw-ring-offset-width: 0px;\n      --tw-ring-offset-color: #fff;\n      --tw-ring-offset-shadow: 0 0 #0000;\n    }\n  }\n}\n";

const ProtoSudoku = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.tag = 'proto-sudoku';
        this.platform = 'vercel';
    }
    componentDidLoad() {
        actions.initApp(this.platform);
    }
    render() {
        return (index.h("div", { key: '9f50eec975c4da5f4984b80380067d5155dda0d1', id: "app", class: "ds1-main relative max-w-min p-0.5" }, index.h(Eswat2Io, { key: 'e7bab7e257022a9920f8b43785d9dc33ab7fed65' }), index.h(Header, { key: 'd8c32e6b9c20b9fe6c8ff2e9fc7a9900057a2679' }, "Sudoku"), index.h(SudokuBoard, { key: '8a028015ae4380aaa54a406ccf5cc908816ca6a4' }), index.h(Keys, { key: '951b6d20ca7a99ced4c60aa39fe040af6e96dd46' }), index.h("hr", { key: '35ba2812a3b068b21b5252c5f07d0b5dc2f18527', class: "ml-0 mr-0" }), index.h(ToolBar, { key: '114e7edd4bf3da82ae344f56cb7e856ce17a6da8' }), index.h(Alerts, { key: '2c15eb0ba714d1e0c378882c62ce575c428adc2a' })));
    }
};
ProtoSudoku.style = shadowCss;

exports.proto_sudoku = ProtoSudoku;
